# Table of Contents

- [planning-transformations-for-sap-solutions](<./planning-transformations-for-sap-solutions.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Planning Transformations for SAP Solutions](<./Planning-Transformations-for-SAP-Solutions.md>)
  - [Introduction](<./Planning-Transformations-for-SAP-Solutions/Introduction.md>)
  - [Planning Transformations for Suggested SAP Solutions](<./Planning-Transformations-for-SAP-Solutions/Planning-Transformations-for-Suggested-SAP-Solutions.md>)
